Length

Type Alias Length 

pub type Length<V> = Quantity<dyn Dimension<N = Z0, M = Z0, Th = Z0, L = PInt<UInt<UTerm, B1>>, I = Z0, Kind = dyn Kind, J = Z0, T = Z0>, dyn Units<V, thermodynamic_temperature = kelvin, luminous_intensity = candela, mass = kilogram, time = second, amount_of_substance = mole, electric_current = ampere, length = meter>, V>;
Quantity type alias using the default base units parameterized on the underlying storage type.

Generic Parameters

  • V: Underlying storage type.

Aliased Type

#[repr(transparent)]
pub struct Length<V> { pub dimension: PhantomData<dyn Dimension<N = Z0, M = Z0, Th = Z0, L = PInt<UInt<UTerm, B1>>, I = Z0, Kind = dyn Kind, J = Z0, T = Z0>>, pub units: PhantomData<dyn Units<V, thermodynamic_temperature = kelvin, luminous_intensity = candela, mass = kilogram, time = second, amount_of_substance = mole, electric_current = ampere, length = meter>>, pub value: V, }

Fields

dimension: PhantomData<dyn Dimension<N = Z0, M = Z0, Th = Z0, L = PInt<UInt<UTerm, B1>>, I = Z0, Kind = dyn Kind, J = Z0, T = Z0>>

Quantity dimension. See Dimension.

units: PhantomData<dyn Units<V, thermodynamic_temperature = kelvin, luminous_intensity = candela, mass = kilogram, time = second, amount_of_substance = mole, electric_current = ampere, length = meter>>

Quantity base units. See Units.

value: V

Quantity value stored in the base units for the quantity.